deframe2: Convert data frame to named vector

Description Usage Arguments

View source: R/params.R

Description

deframe2 converts two-column data frames to a named vector, using the first column as the value and the second column as the name. This is the opposite behavior of tibble::deframe(). Such named vectors are often useful for shiny::selectInput() and others.

Usage

1

Arguments

x

An atomic vector (for enframe()) or a data frame with one or two columns (for deframe()).


maxheld83/shinySurvey documentation built on May 21, 2020, 3:26 p.m.