Description Usage Arguments Value Storing longer strings
Retrieve paths to longer strings Returns paths to (markdown) files containing longer string parameters.
1 | strings_from_mdfile(filenames = NULL, path)
|
filenames |
|
path |
|
[character()] giving absolute paths to files, named by filenames without extension.
Longer strings, such as for survey questions or user interface are often best edited in separate files with proper markup (markdown) support.
In the context of a package, they are best saved ininst/, which can be conveniently accessed with system.file().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.